==> sumus-6.3.1-sources.jar: io/intino/sumus/graph/OnClickRecord.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class OnClickRecord extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {

	protected io.intino.sumus.graph.OnClickRecord.Open open;
	protected io.intino.sumus.graph.OnClickRecord.OpenPanel openPanel;
	protected io.intino.sumus.graph.OnClickRecord.OpenDialog openDialog;

	public OnClickRecord(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.sumus.graph.OnClickRecord.Open open() {
		return open;
	}

	public io.intino.sumus.graph.OnClickRecord.OpenPanel openPanel() {
		return openPanel;
	}

	public io.intino.sumus.graph.OnClickRecord.OpenDialog openDialog() {
		return openDialog;
	}

	public OnClickRecord open(io.intino.sumus.graph.OnClickRecord.Open value) {
		this.open = value;
		return (OnClickRecord) this;
	}

	public OnClickRecord openPanel(io.intino.sumus.graph.OnClickRecord.OpenPanel value) {
		this.openPanel = value;
		return (OnClickRecord) this;
	}

	public OnClickRecord openDialog(io.intino.sumus.graph.OnClickRecord.OpenDialog value) {
		this.openDialog = value;
		return (OnClickRecord) this;
	}

	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		if (open != null) components.add(this.open.core$());
		if (openPanel != null) components.add(this.openPanel.core$());
		if (openDialog != null) components.add(this.openDialog.core$());
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("OnClickRecord$Open")) this.open = node.as(io.intino.sumus.graph.OnClickRecord.Open.class);
		if (node.is("OnClickRecord$OpenPanel")) this.openPanel = node.as(io.intino.sumus.graph.OnClickRecord.OpenPanel.class);
		if (node.is("OnClickRecord$OpenDialog")) this.openDialog = node.as(io.intino.sumus.graph.OnClickRecord.OpenDialog.class);
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("OnClickRecord$Open")) this.open = null;
        if (node.is("OnClickRecord$OpenPanel")) this.openPanel = null;
        if (node.is("OnClickRecord$OpenDialog")) this.openDialog = null;
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}



		public io.intino.sumus.graph.OnClickRecord.OpenPanel openPanel() {
		    io.intino.sumus.graph.OnClickRecord.OpenPanel newElement = core$().graph().concept(io.intino.sumus.graph.OnClickRecord.OpenPanel.class).createNode(name, core$()).as(io.intino.sumus.graph.OnClickRecord.OpenPanel.class);

		    return newElement;
		}

		public io.intino.sumus.graph.OnClickRecord.OpenDialog openDialog(io.intino.sumus.graph.functions.ItemExternalPath path) {
		    io.intino.sumus.graph.OnClickRecord.OpenDialog newElement = core$().graph().concept(io.intino.sumus.graph.OnClickRecord.OpenDialog.class).createNode(name, core$()).as(io.intino.sumus.graph.OnClickRecord.OpenDialog.class);
			newElement.core$().set(newElement, "path", java.util.Collections.singletonList(path));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {





	}

	public static abstract class Open extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {


		public Open(io.intino.tara.magritte.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();

			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}



		}

		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}

	public static class OpenPanel extends io.intino.sumus.graph.OnClickRecord.Open implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Panel panel;

		public OpenPanel(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Panel panel() {
			return panel;
		}

		public OpenPanel panel(io.intino.sumus.graph.Panel value) {
			this.panel = value;
			return (OpenPanel) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("panel", this.panel != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.panel)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("panel")) this.panel = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Panel.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("panel")) this.panel = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Panel.class) : null;
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}

	public static class OpenDialog extends io.intino.sumus.graph.OnClickRecord.Open implements io.intino.tara.magritte.tags.Terminal {
		protected int width;
		protected int height;
		protected io.intino.sumus.graph.functions.ItemExternalPath path;

		public OpenDialog(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public int width() {
			return width;
		}

		public int height() {
			return height;
		}

		public String path(String item) {
			return path.path(item);
		}

		public OpenDialog width(int value) {
			this.width = value;
			return (OpenDialog) this;
		}

		public OpenDialog height(int value) {
			this.height = value;
			return (OpenDialog) this;
		}

		public OpenDialog path(io.intino.sumus.graph.functions.ItemExternalPath value) {
			this.path = io.intino.tara.magritte.loaders.FunctionLoader.load(path, this, io.intino.sumus.graph.functions.ItemExternalPath.class);
			return (OpenDialog) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("width", new java.util.ArrayList(java.util.Collections.singletonList(this.width)));
			map.put("height", new java.util.ArrayList(java.util.Collections.singletonList(this.height)));
			map.put("path", this.path != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.path)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("width")) this.width = io.intino.tara.magritte.loaders.IntegerLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("height")) this.height = io.intino.tara.magritte.loaders.IntegerLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("path")) this.path = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.ItemExternalPath.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("width")) this.width = (java.lang.Integer) values.get(0);
			else if (name.equalsIgnoreCase("height")) this.height = (java.lang.Integer) values.get(0);
			else if (name.equalsIgnoreCase("path")) this.path = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.ItemExternalPath.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/OnClickRecord.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;
import io.intino.sumus.graph.Record;


public class OnClickRecord extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {

	protected io.intino.sumus.graph.OnClickRecord.Open open;
	protected io.intino.sumus.graph.OnClickRecord.OpenPanel openPanel;
	protected io.intino.sumus.graph.OnClickRecord.OpenDialog openDialog;

	public OnClickRecord(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public io.intino.sumus.graph.OnClickRecord.Open open() {
		return open;
	}

	public io.intino.sumus.graph.OnClickRecord.OpenPanel openPanel() {
		return openPanel;
	}

	public io.intino.sumus.graph.OnClickRecord.OpenDialog openDialog() {
		return openDialog;
	}

	public OnClickRecord open(io.intino.sumus.graph.OnClickRecord.Open value) {
		this.open = value;
		return (OnClickRecord) this;
	}

	public OnClickRecord openPanel(io.intino.sumus.graph.OnClickRecord.OpenPanel value) {
		this.openPanel = value;
		return (OnClickRecord) this;
	}

	public OnClickRecord openDialog(io.intino.sumus.graph.OnClickRecord.OpenDialog value) {
		this.openDialog = value;
		return (OnClickRecord) this;
	}

	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		if (open != null) components.add(this.open.core$());
		if (openPanel != null) components.add(this.openPanel.core$());
		if (openDialog != null) components.add(this.openDialog.core$());
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("OnClickRecord$Open")) this.open = node.as(io.intino.sumus.graph.OnClickRecord.Open.class);
		if (node.is("OnClickRecord$OpenPanel")) this.openPanel = node.as(io.intino.sumus.graph.OnClickRecord.OpenPanel.class);
		if (node.is("OnClickRecord$OpenDialog")) this.openDialog = node.as(io.intino.sumus.graph.OnClickRecord.OpenDialog.class);
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("OnClickRecord$Open")) this.open = null;
        if (node.is("OnClickRecord$OpenPanel")) this.openPanel = null;
        if (node.is("OnClickRecord$OpenDialog")) this.openDialog = null;
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create  {
		protected final java.lang.String name;

		public Create(java.lang.String name) {
			this.name = name;
		}



		public io.intino.sumus.graph.OnClickRecord.OpenPanel openPanel() {
		    io.intino.sumus.graph.OnClickRecord.OpenPanel newElement = core$().graph().concept(io.intino.sumus.graph.OnClickRecord.OpenPanel.class).createNode(name, core$()).as(io.intino.sumus.graph.OnClickRecord.OpenPanel.class);

		    return newElement;
		}

		public io.intino.sumus.graph.OnClickRecord.OpenDialog openDialog(io.intino.sumus.graph.functions.ItemExternalPath path) {
		    io.intino.sumus.graph.OnClickRecord.OpenDialog newElement = core$().graph().concept(io.intino.sumus.graph.OnClickRecord.OpenDialog.class).createNode(name, core$()).as(io.intino.sumus.graph.OnClickRecord.OpenDialog.class);
			newElement.core$().set(newElement, "path", java.util.Collections.singletonList(path));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {





	}

	public static abstract class Open extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {


		public Open(io.intino.tara.magritte.Node node) {
			super(node);
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();

			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
		}

		public Create create() {
			return new Create(null);
		}

		public Create create(java.lang.String name) {
			return new Create(name);
		}

		public class Create  {
			protected final java.lang.String name;

			public Create(java.lang.String name) {
				this.name = name;
			}



		}

		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}

	public static class OpenPanel extends io.intino.sumus.graph.OnClickRecord.Open implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Panel panel;
		protected io.intino.sumus.graph.functions.BreadcrumbsTree breadcrumbs;

		public OpenPanel(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Panel panel() {
			return panel;
		}

		public io.intino.sumus.graph.functions.Tree breadcrumbs(Record record, String username) {
			return breadcrumbs.value(record, username);
		}

		public OpenPanel panel(io.intino.sumus.graph.Panel value) {
			this.panel = value;
			return (OpenPanel) this;
		}

		public OpenPanel breadcrumbs(io.intino.sumus.graph.functions.BreadcrumbsTree value) {
			this.breadcrumbs = io.intino.tara.magritte.loaders.FunctionLoader.load(breadcrumbs, this, io.intino.sumus.graph.functions.BreadcrumbsTree.class);
			return (OpenPanel) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("panel", this.panel != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.panel)) : java.util.Collections.emptyList());
			map.put("breadcrumbs", this.breadcrumbs != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.breadcrumbs)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("panel")) this.panel = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Panel.class, this).get(0);
			else if (name.equalsIgnoreCase("breadcrumbs")) this.breadcrumbs = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.BreadcrumbsTree.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("panel")) this.panel = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Panel.class) : null;
			else if (name.equalsIgnoreCase("breadcrumbs")) this.breadcrumbs = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.BreadcrumbsTree.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}

	public static class OpenDialog extends io.intino.sumus.graph.OnClickRecord.Open implements io.intino.tara.magritte.tags.Terminal {
		protected int width;
		protected int height;
		protected io.intino.sumus.graph.functions.ItemExternalPath path;

		public OpenDialog(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public int width() {
			return width;
		}

		public int height() {
			return height;
		}

		public String path(String item) {
			return path.path(item);
		}

		public OpenDialog width(int value) {
			this.width = value;
			return (OpenDialog) this;
		}

		public OpenDialog height(int value) {
			this.height = value;
			return (OpenDialog) this;
		}

		public OpenDialog path(io.intino.sumus.graph.functions.ItemExternalPath value) {
			this.path = io.intino.tara.magritte.loaders.FunctionLoader.load(path, this, io.intino.sumus.graph.functions.ItemExternalPath.class);
			return (OpenDialog) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());
			map.put("width", new java.util.ArrayList(java.util.Collections.singletonList(this.width)));
			map.put("height", new java.util.ArrayList(java.util.Collections.singletonList(this.height)));
			map.put("path", this.path != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.path)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("width")) this.width = io.intino.tara.magritte.loaders.IntegerLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("height")) this.height = io.intino.tara.magritte.loaders.IntegerLoader.load(values, this).get(0);
			else if (name.equalsIgnoreCase("path")) this.path = io.intino.tara.magritte.loaders.FunctionLoader.load(values, this, io.intino.sumus.graph.functions.ItemExternalPath.class).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("width")) this.width = (java.lang.Integer) values.get(0);
			else if (name.equalsIgnoreCase("height")) this.height = (java.lang.Integer) values.get(0);
			else if (name.equalsIgnoreCase("path")) this.path = io.intino.tara.magritte.loaders.FunctionLoader.load(values.get(0), this, io.intino.sumus.graph.functions.ItemExternalPath.class);
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
